@@ -18,8 +18,10 @@
 
 package org.apache.skywalking.oap.server.storage.plugin.elasticsearch.base;
 
+import com.fasterxml.jackson.core.type.TypeReference;
 import com.google.gson.Gson;
 import java.io.IOException;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -28,13 +30,16 @@ import lombok.extern.slf4j.Slf4j;
 import org.apache.skywalking.library.elasticsearch.response.Index;
 import org.apache.skywalking.library.elasticsearch.response.IndexTemplate;
 import org.apache.skywalking.library.elasticsearch.response.Mappings;
+import org.apache.skywalking.oap.server.core.RunningMode;
 import org.apache.skywalking.oap.server.core.storage.StorageException;
+import org.apache.skywalking.oap.server.core.storage.annotation.ElasticSearch;
 import org.apache.skywalking.oap.server.core.storage.model.Model;
 import org.apache.skywalking.oap.server.core.storage.model.ModelColumn;
 import org.apache.skywalking.oap.server.core.storage.model.ModelInstaller;
 import org.apache.skywalking.oap.server.library.client.Client;
 import org.apache.skywalking.oap.server.library.client.elasticsearch.ElasticSearchClient;
 import org.apache.skywalking.oap.server.library.module.ModuleManager;
+import org.apache.skywalking.oap.server.library.util.CollectionUtils;
 import org.apache.skywalking.oap.server.library.util.StringUtil;
 import org.apache.skywalking.oap.server.storage.plugin.elasticsearch.StorageModuleElasticsearchConfig;
 
@@ -43,7 +48,7 @@ public class StorageEsInstaller extends ModelInstaller {
     private final Gson gson = new Gson();
     private final StorageModuleElasticsearchConfig config;
     protected final ColumnTypeEsMapping columnTypeEsMapping;
-
+    private final Map<String, Map<String, Object>> specificIndexesSettings;
 
     /**
      * The mappings of the template .
@@ -57,6 +62,13 @@ public class StorageEsInstaller extends ModelInstaller {
         this.columnTypeEsMapping = new ColumnTypeEsMapping();
         this.config = config;
         this.structures = getStructures();
+        if (StringUtil.isNotEmpty(config.getSpecificIndexSettings())) {
+            this.specificIndexesSettings = gson.fromJson(
+                config.getSpecificIndexSettings(), new TypeReference<Map<String, Map<String, Object>>>() {
+                }.getType());
+        } else {
+            this.specificIndexesSettings = Collections.emptyMap();
+        }
     }
 
     protected IndexStructures getStructures() {
@@ -64,43 +76,56 @@ public class StorageEsInstaller extends ModelInstaller {
     }
 
     @Override
-    protected boolean isExists(Model model) {
+    public boolean isExists(Model model) throws StorageException {
         ElasticSearchClient esClient = (ElasticSearchClient) client;
         String tableName = IndexController.INSTANCE.getTableName(model);
         IndexController.LogicIndicesRegister.registerRelation(model, tableName);
         if (!model.isTimeSeries()) {
             boolean exist = esClient.isExistsIndex(tableName);
             if (exist) {
-                Mappings historyMapping = esClient.getIndex(tableName)
-                                                  .map(Index::getMappings)
-                                                  .orElseGet(Mappings::new);
-                structures.putStructure(tableName, historyMapping);
-                exist = structures.containsStructure(tableName, createMapping(model));
+                Optional<Index> index = esClient.getIndex(tableName);
+                Mappings historyMapping = index.map(Index::getMappings).orElseGet(Mappings::new);
+                structures.putStructure(tableName, historyMapping, index.map(Index::getSettings).orElseGet(HashMap::new));
+                boolean containsMapping = structures.containsMapping(tableName, createMapping(model));
+                // Do not check index settings in the "no-init mode",
+                // because the no-init mode OAP server doesn't take responsibility for index settings.
+                if (RunningMode.isNoInitMode()) {
+                    exist = containsMapping;
+                } else {
+                    exist = containsMapping && structures.compareIndexSetting(tableName, createSetting(model));
+                }
             }
             return exist;
         }
+
         boolean templateExists = esClient.isExistsTemplate(tableName);
         final Optional<IndexTemplate> template = esClient.getTemplate(tableName);
-        boolean lastIndexExists = esClient.isExistsIndex(TimeSeriesUtils.latestWriteIndexName(model));
 
         if ((templateExists && !template.isPresent()) || (!templateExists && template.isPresent())) {
             throw new Error("[Bug warning] ElasticSearch client query template result is not consistent. " +
                                 "Please file an issue to Apache SkyWalking.(https://github.com/apache/skywalking/issues)");
         }
 
-        boolean exist = templateExists && lastIndexExists;
+        boolean exist = templateExists;
 
         if (exist) {
             structures.putStructure(
-                tableName, template.get().getMappings()
+                tableName, template.get().getMappings(), template.get().getSettings()
             );
-            exist = structures.containsStructure(tableName, createMapping(model));
+            boolean containsMapping = structures.containsMapping(tableName, createMapping(model));
+            // Do not check index settings in the "no-init mode",
+            // because the no-init mode OAP server doesn't take responsibility for index settings.
+            if (RunningMode.isNoInitMode()) {
+                exist = containsMapping;
+            } else {
+                exist = containsMapping && structures.compareIndexSetting(tableName, createSetting(model));
+            }
         }
         return exist;
     }
 
     @Override
-    protected void createTable(Model model) throws StorageException {
+    public void createTable(Model model) throws StorageException {
         if (model.isTimeSeries()) {
             createTimeSeriesTable(model);
         } else {
@@ -112,28 +137,36 @@ public class StorageEsInstaller extends ModelInstaller {
         ElasticSearchClient esClient = (ElasticSearchClient) client;
         String tableName = IndexController.INSTANCE.getTableName(model);
         Mappings mapping = createMapping(model);
+        Map<String, Object> settings = createSetting(model);
         if (!esClient.isExistsIndex(tableName)) {
-            Map<String, Object> settings = createSetting(model);
             boolean isAcknowledged = esClient.createIndex(tableName, mapping, settings);
             log.info("create {} index finished, isAcknowledged: {}", tableName, isAcknowledged);
             if (!isAcknowledged) {
-                throw new StorageException("create " + tableName + " index failure, ");
+                throw new StorageException("create " + tableName + " index failure");
             }
         } else {
             Mappings historyMapping = esClient.getIndex(tableName)
                                               .map(Index::getMappings)
                                               .orElseGet(Mappings::new);
-            structures.putStructure(tableName, mapping);
-            Mappings appendMapping = structures.diffStructure(tableName, historyMapping);
+            structures.putStructure(tableName, mapping, settings);
+            Mappings appendMapping = structures.diffMappings(tableName, historyMapping);
+            //update mapping
             if (appendMapping.getProperties() != null && !appendMapping.getProperties().isEmpty()) {
                 boolean isAcknowledged = esClient.updateIndexMapping(tableName, appendMapping);
-                log.info("update {} index finished, isAcknowledged: {}, append mappings: {}", tableName,
+                log.info("update {} index mapping finished, isAcknowledged: {}, append mapping: {}", tableName,
                          isAcknowledged, appendMapping
                 );
                 if (!isAcknowledged) {
-                    throw new StorageException("update " + tableName + " index failure");
+                    throw new StorageException("update " + tableName + " index mapping failure");
                 }
             }
+            //needs to update settings
+            if (!structures.compareIndexSetting(tableName, settings)) {
+                log.warn(
+                    "index {} settings configuration has been updated to {}, please remove it before OAP starts",
+                    tableName, settings
+                );
+            }
         }
     }
 
@@ -145,9 +178,11 @@ public class StorageEsInstaller extends ModelInstaller {
         String indexName = TimeSeriesUtils.latestWriteIndexName(model);
         try {
             boolean shouldUpdateTemplate = !esClient.isExistsTemplate(tableName);
-            shouldUpdateTemplate = shouldUpdateTemplate || !structures.containsStructure(tableName, mapping);
+            shouldUpdateTemplate = shouldUpdateTemplate
+                || !structures.containsMapping(tableName, mapping)
+                || !structures.compareIndexSetting(tableName, settings);
             if (shouldUpdateTemplate) {
-                structures.putStructure(tableName, mapping);
+                structures.putStructure(tableName, mapping, settings);
                 boolean isAcknowledged = esClient.createOrUpdateTemplate(
                     tableName, settings, structures.getMapping(tableName), config.getIndexTemplateOrder());
                 log.info("create {} index template finished, isAcknowledged: {}", tableName, isAcknowledged);
@@ -158,18 +193,27 @@ public class StorageEsInstaller extends ModelInstaller {
 
             if (esClient.isExistsIndex(indexName)) {
                 Mappings historyMapping = esClient.getIndex(indexName)
-                        .map(Index::getMappings)
-                        .orElseGet(Mappings::new);
-                Mappings appendMapping = structures.diffStructure(tableName, historyMapping);
+                                                  .map(Index::getMappings)
+                                                  .orElseGet(Mappings::new);
+                Mappings appendMapping = structures.diffMappings(tableName, historyMapping);
+                //update mapping
                 if (appendMapping.getProperties() != null && !appendMapping.getProperties().isEmpty()) {
                     boolean isAcknowledged = esClient.updateIndexMapping(indexName, appendMapping);
                     log.info("update {} index finished, isAcknowledged: {}, append mappings: {}", indexName,
-                            isAcknowledged, appendMapping
+                             isAcknowledged, appendMapping
                     );
                     if (!isAcknowledged) {
                         throw new StorageException("update " + indexName + " time series index failure");
                     }
                 }
+
+                //needs to update settings
+                if (!structures.compareIndexSetting(tableName, settings)) {
+                    log.info(
+                        "index template {} settings configuration has been updated to {}, it will applied on new index",
+                        tableName, settings
+                    );
+                }
             } else {
                 boolean isAcknowledged = esClient.createIndex(indexName);
                 log.info("create {} index finished, isAcknowledged: {}", indexName, isAcknowledged);
@@ -184,13 +228,14 @@ public class StorageEsInstaller extends ModelInstaller {
 
     protected Map<String, Object> createSetting(Model model) throws StorageException {
         Map<String, Object> setting = new HashMap<>();
-
-        setting.put("index.number_of_replicas", model.isSuperDataset()
-            ? config.getSuperDatasetIndexReplicasNumber()
-            : config.getIndexReplicasNumber());
-        setting.put("index.number_of_shards", model.isSuperDataset()
-            ? config.getIndexShardsNumber() * config.getSuperDatasetIndexShardsFactor()
-            : config.getIndexShardsNumber());
+        Map<String, Object> indexSettings = new HashMap<>();
+        setting.put("index", indexSettings);
+        indexSettings.put("number_of_replicas", model.isSuperDataset()
+            ? Integer.toString(config.getSuperDatasetIndexReplicasNumber())
+            : Integer.toString(config.getIndexReplicasNumber()));
+        indexSettings.put("number_of_shards", model.isSuperDataset()
+            ? Integer.toString(config.getIndexShardsNumber() * config.getSuperDatasetIndexShardsFactor())
+            : Integer.toString(config.getIndexShardsNumber()));
         // Set the index refresh period as INT(flushInterval * 2/3). At the edge case,
         // in low traffic(traffic < bulkActions in the whole period), there is a possible case, 2 period bulks are included in
         // one index refresh rebuild operation, which could cause version conflicts. And this case can't be fixed
@@ -203,18 +248,42 @@ public class StorageEsInstaller extends ModelInstaller {
             // even this value is set too small by end user manually.
             indexRefreshInterval = 5;
         }
-        setting.put("index.refresh_interval", indexRefreshInterval + "s");
-        List<ModelColumn> columns = IndexController.LogicIndicesRegister.getPhysicalTableColumns(model);
-        setting.put("analysis", getAnalyzerSetting(columns));
+        indexSettings.put("refresh_interval", indexRefreshInterval + "s");
+        indexSettings.put("analysis", getAnalyzerSetting(model));
         if (!StringUtil.isEmpty(config.getAdvanced())) {
             Map<String, Object> advancedSettings = gson.fromJson(config.getAdvanced(), Map.class);
             setting.putAll(advancedSettings);
         }
+
+        //Set the config for the specific index, if has been configured.
+        Map<String, Object> specificSettings = this.specificIndexesSettings.get(IndexController.INSTANCE.getTableName(model));
+        if (!CollectionUtils.isEmpty(specificSettings)) {
+            indexSettings.putAll(specificSettings);
+        }
+        
         return setting;
     }
 
-    private Map getAnalyzerSetting(List<ModelColumn> analyzerTypes) throws StorageException {
+    //In the `No-Sharding Mode`:
+    //https://skywalking.apache.org/docs/main/next/en/faq/new-elasticsearch-storage-option-explanation-in-9.2.0/
+    //Some of models require a analyzer to run match query, some others are not.
+    //They are merged into the one physical index(metrics-all or record-all)
+    //When adding a new model(with an analyzer) into an existed index by update will be failed, if the index is without analyzer settings.
+    //To avoid this, add the analyzer settings to the template before index creation.
+    private Map getAnalyzerSetting(Model model) throws StorageException {
+        if (config.isLogicSharding() || !model.isTimeSeries()) {
+            return getAnalyzerSettingByColumn(model);
+        } else if (IndexController.INSTANCE.isRecordModel(model) && model.isSuperDataset()) {
+            //SuperDataset doesn't merge index, the analyzer follow the column config.
+            return getAnalyzerSettingByColumn(model);
+        } else {
+            return getAnalyzerSetting4MergedIndex(model);
+        }
+    }
+
+    private Map getAnalyzerSettingByColumn(Model model) throws StorageException {
         AnalyzerSetting analyzerSetting = new AnalyzerSetting();
+        List<ModelColumn> analyzerTypes = IndexController.LogicIndicesRegister.getPhysicalTableColumns(model);
         for (final ModelColumn column : analyzerTypes) {
             if (!column.getElasticSearchExtension().needMatchQuery()) {
                 continue;
@@ -228,6 +297,16 @@ public class StorageEsInstaller extends ModelInstaller {
         return gson.fromJson(gson.toJson(analyzerSetting), Map.class);
     }
 
+    //Indexes `metrics-all and records-all` are required `OAP_ANALYZER`
+    private Map getAnalyzerSetting4MergedIndex(Model model) throws StorageException {
+        AnalyzerSetting setting = AnalyzerSetting.Generator.getGenerator(
+                                                     ElasticSearch.MatchQuery.AnalyzerType.OAP_ANALYZER)
+                                                           .getGenerateFunc()
+                                                           .generate(config);
+
+        return gson.fromJson(gson.toJson(setting), Map.class);
+    }
+
     protected Mappings createMapping(Model model) {
         Map<String, Object> properties = new HashMap<>();
         Mappings.Source source = new Mappings.Source();
