@@ -38,6 +38,7 @@ import org.apache.skywalking.oap.server.core.analysis.manual.relation.process.Pr
 import org.apache.skywalking.oap.server.core.analysis.manual.relation.service.ServiceRelationClientSideMetrics;
 import org.apache.skywalking.oap.server.core.analysis.manual.relation.service.ServiceRelationServerSideMetrics;
 import org.apache.skywalking.oap.server.core.analysis.metrics.Metrics;
+import org.apache.skywalking.oap.server.core.query.input.Duration;
 import org.apache.skywalking.oap.server.core.query.type.Call;
 import org.apache.skywalking.oap.server.core.source.DetectPoint;
 import org.apache.skywalking.oap.server.core.storage.query.ITopologyQueryDAO;
@@ -53,43 +54,40 @@ public class TopologyQueryEsDAO extends EsDAO implements ITopologyQueryDAO {
     }
 
     @Override
-    public List<Call.CallDetail> loadServiceRelationsDetectedAtServerSide(
-        long startTB, long endTB, List<String> serviceIds) {
+    public List<Call.CallDetail> loadServiceRelationsDetectedAtServerSide(Duration duration, List<String> serviceIds) {
         if (CollectionUtils.isEmpty(serviceIds)) {
             throw new UnexpectedException("Service id is empty");
         }
 
         final SearchBuilder sourceBuilder = Search.builder().size(0);
-        setQueryCondition(sourceBuilder, startTB, endTB, serviceIds, ServiceRelationServerSideMetrics.INDEX_NAME);
+        setQueryCondition(sourceBuilder, duration, serviceIds, ServiceRelationServerSideMetrics.INDEX_NAME);
 
         return buildServiceRelation(
             sourceBuilder, ServiceRelationServerSideMetrics.INDEX_NAME, DetectPoint.SERVER);
     }
 
     @Override
-    public List<Call.CallDetail> loadServiceRelationDetectedAtClientSide(long startTB,
-                                                                         long endTB,
+    public List<Call.CallDetail> loadServiceRelationDetectedAtClientSide(Duration duration,
                                                                          List<String> serviceIds) {
         if (CollectionUtils.isEmpty(serviceIds)) {
             throw new UnexpectedException("Service id is empty");
         }
 
         final SearchBuilder sourceBuilder = Search.builder().size(0);
-        setQueryCondition(sourceBuilder, startTB, endTB, serviceIds, ServiceRelationClientSideMetrics.INDEX_NAME);
+        setQueryCondition(sourceBuilder, duration, serviceIds, ServiceRelationClientSideMetrics.INDEX_NAME);
 
         return buildServiceRelation(
             sourceBuilder, ServiceRelationClientSideMetrics.INDEX_NAME, DetectPoint.CLIENT);
     }
 
     @Override
-    public List<Call.CallDetail> loadServiceRelationsDetectedAtServerSide(long startTB,
-                                                                          long endTB) {
+    public List<Call.CallDetail> loadServiceRelationsDetectedAtServerSide(Duration duration) {
         SearchBuilder sourceBuilder = Search.builder();
         final BoolQueryBuilder query = Query.bool()
                                             .must(Query.range(ServiceRelationServerSideMetrics.TIME_BUCKET)
-                                                       .gte(startTB)
-                                                       .lte(endTB));
-        if (IndexController.LogicIndicesRegister.isPhysicalTable(ServiceRelationServerSideMetrics.INDEX_NAME)) {
+                                                       .gte(duration.getStartTimeBucket())
+                                                       .lte(duration.getEndTimeBucket()));
+        if (IndexController.LogicIndicesRegister.isMergedTable(ServiceRelationServerSideMetrics.INDEX_NAME)) {
             query.must(Query.term(IndexController.LogicIndicesRegister.METRIC_TABLE_NAME, ServiceRelationServerSideMetrics.INDEX_NAME));
         }
         sourceBuilder.query(query).size(0);
@@ -99,14 +97,13 @@ public class TopologyQueryEsDAO extends EsDAO implements ITopologyQueryDAO {
     }
 
     @Override
-    public List<Call.CallDetail> loadServiceRelationDetectedAtClientSide(long startTB,
-                                                                         long endTB) {
+    public List<Call.CallDetail> loadServiceRelationDetectedAtClientSide(Duration duration) {
         SearchBuilder sourceBuilder = Search.builder();
         final BoolQueryBuilder query = Query.bool()
                                             .must(Query.range(ServiceRelationClientSideMetrics.TIME_BUCKET)
-                                                       .gte(startTB)
-                                                       .lte(endTB));
-        if (IndexController.LogicIndicesRegister.isPhysicalTable(ServiceRelationClientSideMetrics.INDEX_NAME)) {
+                                                       .gte(duration.getStartTimeBucket())
+                                                       .lte(duration.getEndTimeBucket()));
+        if (IndexController.LogicIndicesRegister.isMergedTable(ServiceRelationClientSideMetrics.INDEX_NAME)) {
             query.must(Query.term(IndexController.LogicIndicesRegister.METRIC_TABLE_NAME, ServiceRelationClientSideMetrics.INDEX_NAME));
         }
         sourceBuilder.query(query).size(0);
@@ -118,10 +115,9 @@ public class TopologyQueryEsDAO extends EsDAO implements ITopologyQueryDAO {
     @Override
     public List<Call.CallDetail> loadInstanceRelationDetectedAtServerSide(String clientServiceId,
                                                                           String serverServiceId,
-                                                                          long startTB,
-                                                                          long endTB) {
+                                                                          Duration duration) {
         final SearchBuilder search = Search.builder().size(0);
-        setInstanceQueryCondition(search, startTB, endTB, clientServiceId, serverServiceId, ServiceInstanceRelationServerSideMetrics.INDEX_NAME);
+        setInstanceQueryCondition(search, duration, clientServiceId, serverServiceId, ServiceInstanceRelationServerSideMetrics.INDEX_NAME);
 
         return buildInstanceRelation(
             search, ServiceInstanceRelationServerSideMetrics.INDEX_NAME, DetectPoint.SERVER);
@@ -130,16 +126,15 @@ public class TopologyQueryEsDAO extends EsDAO implements ITopologyQueryDAO {
     @Override
     public List<Call.CallDetail> loadInstanceRelationDetectedAtClientSide(String clientServiceId,
                                                                           String serverServiceId,
-                                                                          long startTB,
-                                                                          long endTB) {
+                                                                          Duration duration) {
         final SearchBuilder search = Search.builder().size(0);
-        setInstanceQueryCondition(search, startTB, endTB, clientServiceId, serverServiceId, ServiceInstanceRelationClientSideMetrics.INDEX_NAME);
+        setInstanceQueryCondition(search, duration, clientServiceId, serverServiceId, ServiceInstanceRelationClientSideMetrics.INDEX_NAME);
 
         return buildInstanceRelation(
             search, ServiceInstanceRelationClientSideMetrics.INDEX_NAME, DetectPoint.CLIENT);
     }
 
-    private void setInstanceQueryCondition(SearchBuilder search, long startTB, long endTB,
+    private void setInstanceQueryCondition(SearchBuilder search, Duration duration,
                                            String clientServiceId, String serverServiceId, String indexName) {
         final BoolQueryBuilder serverRelationBoolQuery =
             Query.bool()
@@ -175,25 +170,24 @@ public class TopologyQueryEsDAO extends EsDAO implements ITopologyQueryDAO {
         final BoolQueryBuilder boolQuery =
             Query.bool()
                  .must(Query.range(EndpointRelationServerSideMetrics.TIME_BUCKET)
-                            .gte(startTB)
-                            .lte(endTB))
+                            .gte(duration.getStartTimeBucket())
+                            .lte(duration.getEndTimeBucket()))
                  .must(serviceIdBoolQuery);
-        if (IndexController.LogicIndicesRegister.isPhysicalTable(indexName)) {
+        if (IndexController.LogicIndicesRegister.isMergedTable(indexName)) {
             boolQuery.must(Query.term(IndexController.LogicIndicesRegister.METRIC_TABLE_NAME, indexName));
         }
         search.query(boolQuery);
     }
 
     @Override
-    public List<Call.CallDetail> loadEndpointRelation(long startTB, long endTB,
-                                                      String destEndpointId) {
+    public List<Call.CallDetail> loadEndpointRelation(Duration duration, String destEndpointId) {
         SearchBuilder sourceBuilder = Search.builder();
         sourceBuilder.size(0);
 
         BoolQueryBuilder boolQuery = Query.bool();
         boolQuery.must(
             Query.range(EndpointRelationServerSideMetrics.TIME_BUCKET)
-                 .gte(startTB).lte(endTB));
+                 .gte(duration.getStartTimeBucket()).lte(duration.getEndTimeBucket()));
 
         BoolQueryBuilder serviceIdBoolQuery = Query.bool();
         boolQuery.must(serviceIdBoolQuery);
@@ -205,7 +199,7 @@ public class TopologyQueryEsDAO extends EsDAO implements ITopologyQueryDAO {
             Query.term(
                 EndpointRelationServerSideMetrics.DEST_ENDPOINT, destEndpointId
             ));
-        if (IndexController.LogicIndicesRegister.isPhysicalTable(EndpointRelationServerSideMetrics.INDEX_NAME)) {
+        if (IndexController.LogicIndicesRegister.isMergedTable(EndpointRelationServerSideMetrics.INDEX_NAME)) {
             boolQuery.must(Query.term(IndexController.LogicIndicesRegister.METRIC_TABLE_NAME, EndpointRelationServerSideMetrics.INDEX_NAME));
         }
         sourceBuilder.query(boolQuery);
@@ -215,22 +209,22 @@ public class TopologyQueryEsDAO extends EsDAO implements ITopologyQueryDAO {
     }
 
     @Override
-    public List<Call.CallDetail> loadProcessRelationDetectedAtClientSide(String serviceInstanceId, long startTB, long endTB) throws IOException {
-        return buildProcessRelation(serviceInstanceId, startTB, endTB, DetectPoint.CLIENT);
+    public List<Call.CallDetail> loadProcessRelationDetectedAtClientSide(String serviceInstanceId, Duration duration) throws IOException {
+        return buildProcessRelation(serviceInstanceId, duration, DetectPoint.CLIENT);
     }
 
     @Override
-    public List<Call.CallDetail> loadProcessRelationDetectedAtServerSide(String serviceInstanceId, long startTB, long endTB) throws IOException {
-        return buildProcessRelation(serviceInstanceId, startTB, endTB, DetectPoint.SERVER);
+    public List<Call.CallDetail> loadProcessRelationDetectedAtServerSide(String serviceInstanceId, Duration duration) throws IOException {
+        return buildProcessRelation(serviceInstanceId, duration, DetectPoint.SERVER);
     }
 
-    private List<Call.CallDetail> buildProcessRelation(String serviceInstanceId, long startTB, long endTB, DetectPoint detectPoint) throws IOException {
+    private List<Call.CallDetail> buildProcessRelation(String serviceInstanceId, Duration duration, DetectPoint detectPoint) throws IOException {
         final SearchBuilder sourceBuilder = Search.builder().size(0);
         final BoolQueryBuilder query = Query.bool()
                                             .must(Query.term(ProcessRelationServerSideMetrics.SERVICE_INSTANCE_ID, serviceInstanceId))
                                             .must(Query.range(EndpointRelationServerSideMetrics.TIME_BUCKET)
-                                                       .gte(startTB)
-                                                       .lte(endTB));
+                                                       .gte(duration.getStartTimeBucket())
+                                                       .lte(duration.getEndTimeBucket()));
         sourceBuilder.query(query);
         sourceBuilder.aggregation(
             Aggregation
@@ -248,7 +242,7 @@ public class TopologyQueryEsDAO extends EsDAO implements ITopologyQueryDAO {
             ProcessRelationServerSideMetrics.INDEX_NAME : ProcessRelationClientSideMetrics.INDEX_NAME;
 
         final String index = IndexController.LogicIndicesRegister.getPhysicalTableName(indexName);
-        if (IndexController.LogicIndicesRegister.isPhysicalTable(indexName)) {
+        if (IndexController.LogicIndicesRegister.isMergedTable(indexName)) {
             query.must(Query.term(IndexController.LogicIndicesRegister.METRIC_TABLE_NAME, indexName));
         }
         final SearchResponse response = getClient().search(index, sourceBuilder.build());
@@ -380,18 +374,18 @@ public class TopologyQueryEsDAO extends EsDAO implements ITopologyQueryDAO {
         return calls;
     }
 
-    private void setQueryCondition(SearchBuilder search, long startTB, long endTB,
+    private void setQueryCondition(SearchBuilder search, Duration duration,
                                    List<String> serviceIds, String indexName) {
         final BoolQueryBuilder query =
             Query.bool()
                  .must(Query.range(ServiceRelationServerSideMetrics.TIME_BUCKET)
-                            .gte(startTB)
-                            .lte(endTB));
+                            .gte(duration.getStartTimeBucket())
+                            .lte(duration.getEndTimeBucket()));
 
         final BoolQueryBuilder serviceIdBoolQuery = Query.bool();
 
         query.must(serviceIdBoolQuery);
-        if (IndexController.LogicIndicesRegister.isPhysicalTable(indexName)) {
+        if (IndexController.LogicIndicesRegister.isMergedTable(indexName)) {
             query.must(Query.term(IndexController.LogicIndicesRegister.METRIC_TABLE_NAME, indexName));
         }
         if (serviceIds.size() == 1) {
