@@ -52,17 +52,19 @@ const msg = {
   instance: "Instance",
   create: "Create",
   loading: "Loading",
-  selectVisualization: "Visualize your metrics",
+  selectVisualization: "Visualize Metrics",
   visualization: "Visualization",
-  graphStyles: "Graph styles",
-  widgetOptions: "Widget options",
-  standardOptions: "Standard options",
+  graphStyles: "Graph Styles",
+  widgetOptions: "Widget Options",
+  standardOptions: "Standard Options",
   max: "Max",
   min: "Min",
   plus: "Plus",
+  mean: "Mean",
   minus: "Minus",
   multiply: "Multiply",
   divide: "Divide",
+  total: "Total",
   convertToMilliseconds: "Convert Unix Timestamp(milliseconds)",
   convertToSeconds: "Convert Unix Timestamp(seconds)",
   smooth: "Smooth",
@@ -108,6 +110,7 @@ const msg = {
   showXAxis: "Show X Axis",
   showYAxis: "Show Y Axis",
   nameError: "The dashboard name cannot be duplicate",
+  nameEmptyError: "The dashboard name cannot be empty",
   showGroup: "Show Group",
   noRoot: "Please set a root dashboard for",
   noWidget: "Please add widgets.",
@@ -123,6 +126,7 @@ const msg = {
   editWarning: "You are entering edit mode",
   viewWarning: "You are entering view mode",
   virtualDatabase: "Virtual Database",
+  virtualCache: "Virtual Cache",
   reloadDashboards: "Reload dashboards",
   kubernetesService: "Service",
   kubernetesCluster: "Cluster",
@@ -144,6 +148,7 @@ const msg = {
   pause: "Pause",
   begin: "Start",
   associateOptions: "Association Options",
+  associateMetrics: "Association Metrics",
   widget: "Widget",
   nameTip:
     "The name only supports Chinese and English, horizontal lines and underscores. The length of the name is limited to 300 characters",
@@ -152,6 +157,30 @@ const msg = {
   text: "Text",
   query: "Query",
   postgreSQL: "PostgreSQL",
+  endpointTips: "The table shows up to 20 pieces of endpoints.",
+  apisix: "APISIX",
+  viewTrace: "View Related Traces",
+  relatedTraceOptions: "Related Trace Options",
+  setLatencyDuration: "Latency Related Metrics",
+  queryOrder: "Query By Duration",
+  setOrder: "Query Order",
+  latency: "Latency",
+  metricValues: "Metric Values",
+  queryConditions: "Query Conditions",
+  enableRelatedTrace: "Enable Related Trace",
+  maxTraceDuration: "Maximum Duration",
+  minTraceDuration: "Minimum Duration",
+  legendOptions: "Legend Options",
+  showLegend: "Show Legend",
+  asTable: "As Table",
+  toTheRight: "To The Right",
+  legendValues: "Legend Values",
+  minDuration: "Minimal Request Duration",
+  when4xx:
+    "Sample HTTP requests and responses with tracing when response code between 400 and 499",
+  when5xx:
+    "Sample HTTP requests and responses with tracing when response code between 500 and 599",
+  taskTitle: "HTTP request and response collecting rules",
   seconds: "Seconds",
   hourTip: "Select Hour",
   minuteTip: "Select Minute",
@@ -244,7 +273,7 @@ const msg = {
   entityType: "Entity Type",
   maxItemNum: "Max number of Item",
   unknownMetrics: "Unknown Metrics",
-  labels: "Labels",
+  labels: "Label",
   aggregation: "Calculation",
   unit: "Unit",
   labelsIndex: "Label Subscript",
@@ -305,6 +334,7 @@ const msg = {
   eventsParameters: "Event Parameters",
   eventDetail: "Event Detail",
   value: "Value",
+  key: "Key",
   show: "Show",
   hide: "Hide",
   statistics: "Statistics",
@@ -343,5 +373,7 @@ const msg = {
   conditionNotice:
     "Notice: Please press Enter after inputting a key of content, exclude key of content(key=value).",
   language: "Language",
+  gateway: "Gateway",
+  virtualMQ: "Virtual MQ",
 };
 export default msg;
