@@ -25,16 +25,12 @@ export const routesAlarm: Array<RouteRecordRaw> = [
       title: "alarm",
       icon: "spam",
       hasGroup: false,
-      exact: true,
     },
     component: Layout,
     children: [
       {
         path: "/alerting",
         name: "Alarm",
-        meta: {
-          exact: false,
-        },
         component: () =>
           import(/* webpackChunkName: "alerting" */ "@/views/Alarm.vue"),
       },
